@@ -7,6 +7,10 @@ import (
 	"runtime"
 	"strings"
 
+	"github.com/tfsec/tfsec/pkg/result"
+
+	"github.com/tfsec/tfsec/pkg/severity"
+
 	"github.com/tfsec/tfsec/internal/app/tfsec/config"
 	"github.com/tfsec/tfsec/internal/app/tfsec/updater"
 
@@ -20,8 +24,8 @@ import (
 
 	"github.com/spf13/cobra"
 
-	_ "github.com/tfsec/tfsec/internal/app/tfsec/checks"
 	"github.com/tfsec/tfsec/internal/app/tfsec/parser"
+	_ "github.com/tfsec/tfsec/internal/app/tfsec/rules"
 	"github.com/tfsec/tfsec/internal/app/tfsec/scanner"
 	"github.com/tfsec/tfsec/version"
 )
@@ -32,7 +36,7 @@ var disableColours = false
 var format string
 var softFail = false
 var filterResults string
-var excludedChecks string
+var excludedRuleIDs string
 var tfvarsPath string
 var outputFlag string
 var customCheckDir string
@@ -47,14 +51,16 @@ var ignoreWarnings = false
 var ignoreInfo = false
 var allDirs = false
 var runStatistics bool
+var ignoreHCLErrors bool
 
 func init() {
+	rootCmd.Flags().BoolVar(&ignoreHCLErrors, "ignore-hcl-errors", ignoreHCLErrors, "Stop and report an error if an HCL parse error is encountered")
 	rootCmd.Flags().BoolVar(&disableColours, "no-colour", disableColours, "Disable coloured output")
 	rootCmd.Flags().BoolVar(&disableColours, "no-color", disableColours, "Disable colored output (American style!)")
 	rootCmd.Flags().BoolVarP(&showVersion, "version", "v", showVersion, "Show version information and exit")
 	rootCmd.Flags().BoolVar(&runUpdate, "update", runUpdate, "Update to latest version")
 	rootCmd.Flags().StringVarP(&format, "format", "f", format, "Select output format: default, json, csv, checkstyle, junit, sarif")
-	rootCmd.Flags().StringVarP(&excludedChecks, "exclude", "e", excludedChecks, "Provide checks via , without space to exclude from run.")
+	rootCmd.Flags().StringVarP(&excludedRuleIDs, "exclude", "e", excludedRuleIDs, "Provide comma-separated list of rule IDs to exclude from run.")
 	rootCmd.Flags().StringVar(&filterResults, "filter-results", filterResults, "Filter results to return specific checks only (supports comma-delimited input).")
 	rootCmd.Flags().BoolVarP(&softFail, "soft-fail", "s", softFail, "Runs checks but suppresses error code")
 	rootCmd.Flags().StringVar(&tfvarsPath, "tfvars-file", tfvarsPath, "Path to .tfvars file")
@@ -99,17 +105,16 @@ var rootCmd = &cobra.Command{
 
 		if runUpdate {
 			if err := updater.Update(); err != nil {
-				tml.Printf("Not updating, %s\n", err.Error())
+				_ = tml.Printf("Not updating, %s\n", err.Error())
 			}
 			os.Exit(0)
 		}
 	},
-	Run: func(cmd *cobra.Command, args []string) {
+	RunE: func(cmd *cobra.Command, args []string) error {
 
 		var dir string
 		var err error
 		var filterResultsList []string
-		var excludedChecksList []string
 		var outputFile *os.File
 
 		if len(args) == 1 {
@@ -124,14 +129,23 @@ var rootCmd = &cobra.Command{
 		tfsecDir := fmt.Sprintf("%s/.tfsec", dir)
 
 		if len(configFile) > 0 {
-			tfsecConfig = loadConfigFile(configFile)
+			tfsecConfig, err = loadConfigFile(configFile)
+			if err != nil {
+				return err
+			}
 		} else {
 			jsonConfigFile := fmt.Sprintf("%s/%s", tfsecDir, "config.json")
 			yamlConfigFile := fmt.Sprintf("%s/%s", tfsecDir, "config.yml")
 			if _, err = os.Stat(jsonConfigFile); err == nil {
-				tfsecConfig = loadConfigFile(jsonConfigFile)
+				tfsecConfig, err = loadConfigFile(jsonConfigFile)
+				if err != nil {
+					return err
+				}
 			} else if _, err = os.Stat(yamlConfigFile); err == nil {
-				tfsecConfig = loadConfigFile(yamlConfigFile)
+				tfsecConfig, err = loadConfigFile(yamlConfigFile)
+				if err != nil {
+					return err
+				}
 			} else {
 				tfsecConfig = &config.Config{}
 			}
@@ -145,7 +159,7 @@ var rootCmd = &cobra.Command{
 		debug.Log("custom check directory set to %s", customCheckDir)
 		err = custom.Load(customCheckDir)
 		if err != nil {
-			fmt.Fprint(os.Stderr, fmt.Sprintf("There were errors while processing custom check files. %s", err))
+			_, _ = fmt.Fprint(os.Stderr, fmt.Sprintf("There were errors while processing custom check files. %s", err))
 			os.Exit(1)
 		}
 		debug.Log("Custom checks loaded")
@@ -154,10 +168,6 @@ var rootCmd = &cobra.Command{
 			filterResultsList = strings.Split(filterResults, ",")
 		}
 
-		if len(excludedChecks) > 0 {
-			excludedChecksList = strings.Split(excludedChecks, ",")
-		}
-
 		if outputFlag != "" {
 			f, err := os.OpenFile(filepath.Clean(outputFlag), os.O_CREATE|os.O_WRONLY|os.O_TRUNC, 0o600)
 			if err != nil {
@@ -176,32 +186,26 @@ var rootCmd = &cobra.Command{
 			os.Exit(1)
 		}
 
-		if tfvarsPath != "" {
-			tfvarsPath, err = filepath.Abs(tfvarsPath)
-			if err != nil {
-				fmt.Println(err)
-				os.Exit(1)
-			}
-		} else if unusedTfvarsPresent(dir) {
-			tml.Printf("\n<yellow>Warning: A tfvars file was found but not automatically used. \nDid you mean to specify the --tfvars-file flag?</yellow>\n")
+		if tfvarsPath == "" && unusedTfvarsPresent(dir) {
+			_ = tml.Printf("\n<yellow>Warning: A tfvars file was found but not automatically used. \nDid you mean to specify the --tfvars-file flag?</yellow>\n")
 		}
 
 		debug.Log("Starting parser...")
-		blocks, err := parser.New(dir, tfvarsPath, getParserOptions()...).ParseDirectory()
+		blocks, err := parser.New(dir, getParserOptions()...).ParseDirectory()
 		if err != nil {
 			fmt.Println(err)
 			os.Exit(1)
 		}
 
 		debug.Log("Starting scanner...")
-		results := scanner.New().Scan(blocks, mergeWithoutDuplicates(excludedChecksList, tfsecConfig.ExcludedChecks), getScannerOptions()...)
+		results := scanner.New(getScannerOptions()...).Scan(blocks)
 		results = updateResultSeverity(results)
 		results = RemoveDuplicatesAndUnwanted(results, ignoreWarnings, excludeDownloaded)
 		if len(filterResultsList) > 0 {
-			var filteredResult []scanner.Result
+			var filteredResult []result.Result
 			for _, result := range results {
-				for _, checkID := range filterResultsList {
-					if string(result.RuleID) == checkID {
+				for _, ruleID := range filterResultsList {
+					if result.RuleID == ruleID {
 						filteredResult = append(filteredResult, result)
 					}
 				}
@@ -215,49 +219,60 @@ var rootCmd = &cobra.Command{
 				statistics = scanner.AddStatisticsCount(statistics, result)
 			}
 			statistics.PrintStatisticsTable()
-			os.Exit(0)
+			return nil
 		}
 
 		if err := formatter(outputFile, results, dir, getFormatterOptions()...); err != nil {
-			fmt.Println(err)
-			os.Exit(1)
+			return err
 		}
 
 		// Soft fail always takes precedence. If set, only execution errors
 		// produce a failure exit code (1).
 		if softFail {
-			os.Exit(0)
+			return nil
 		}
 
 		if detailedExitCode {
 			os.Exit(getDetailedExitCode(results))
 		}
 
-		// If all failed checks are of INFO severity, then produce a success
+		// If all failed rules are of INFO severity, then produce a success
 		// exit code (0).
 		if allInfo(results) {
-			os.Exit(0)
+			return nil
 		}
 
 		os.Exit(1)
+		return nil
 	},
 }
 
-func getParserOptions() []parser.ParserOption {
-	var opts []parser.ParserOption
+func getParserOptions() []parser.Option {
+	var opts []parser.Option
 	if allDirs {
-		opts = append(opts, parser.DontSearchTfFiles)
+		opts = append(opts, parser.OptionDoNotSearchTfFiles())
+	}
+	if tfvarsPath != "" {
+		tfvarsPath, err := filepath.Abs(tfvarsPath)
+		if err != nil {
+			fmt.Println(err)
+			os.Exit(1)
+		}
+		opts = append(opts, parser.OptionWithTFVarsPath(tfvarsPath))
+	}
+	if !ignoreHCLErrors {
+		opts = append(opts, parser.OptionStopOnHCLError())
 	}
 	return opts
 }
 
-func getDetailedExitCode(results []scanner.Result) int {
-	// If there are no failed checks, then produce a success exit code (0).
+func getDetailedExitCode(results []result.Result) int {
+	// If there are no failed rules, then produce a success exit code (0).
 	if len(results) == 0 || len(results) == countPassedResults(results) {
 		return 0
 	}
 
-	// If there are some failed checks but they are all of INFO severity, then
+	// If there are some failed rules but they are all of INFO severity, then
 	// produce a special failure exit code (2).
 	if allInfo(results) {
 		return 2
@@ -268,28 +283,28 @@ func getDetailedExitCode(results []scanner.Result) int {
 	return 1
 }
 
-func RemoveDuplicatesAndUnwanted(results []scanner.Result, ignoreWarnings bool, excludeDownloaded bool) []scanner.Result {
-	reduction := map[scanner.Result]bool{}
+func RemoveDuplicatesAndUnwanted(results []result.Result, ignoreWarnings bool, excludeDownloaded bool) []result.Result {
+	reduction := make(map[string]result.Result)
 
-	for _, result := range results {
-		reduction[result] = true
+	for _, res := range results {
+		reduction[res.HashCode()] = res
 	}
 
-	var returnVal []scanner.Result
-	for r, _ := range reduction {
-		if excludeDownloaded && strings.Contains(r.Range.Filename, "/.terraform") {
+	var returnVal []result.Result
+	for _, res := range reduction {
+		if excludeDownloaded && strings.Contains(res.Range.Filename, fmt.Sprintf("%c.terraform", os.PathSeparator)) {
 			continue
 		}
 
-		if ignoreWarnings && r.Severity == scanner.SeverityWarning {
+		if ignoreWarnings && res.Severity == severity.Warning {
 			continue
 		}
 
-		if ignoreInfo && r.Severity == scanner.SeverityInfo {
+		if ignoreInfo && res.Severity == severity.Info {
 			continue
 		}
 
-		returnVal = append(returnVal, r)
+		returnVal = append(returnVal, res)
 	}
 	return returnVal
 }
@@ -305,14 +320,22 @@ func getFormatterOptions() []formatters.FormatterOption {
 	return options
 }
 
-func getScannerOptions() []scanner.ScannerOption {
-	var options []scanner.ScannerOption
+func getScannerOptions() []scanner.Option {
+	var options []scanner.Option
 	if includePassed {
-		options = append(options, scanner.IncludePassed)
+		options = append(options, scanner.OptionIncludePassed())
 	}
 	if includeIgnored {
-		options = append(options, scanner.IncludeIgnored)
+		options = append(options, scanner.OptionIncludeIgnored())
 	}
+
+	var allExcludedRuleIDs []string
+	for _, exclude := range strings.Split(excludedRuleIDs, ",") {
+		allExcludedRuleIDs = append(allExcludedRuleIDs, strings.TrimSpace(exclude))
+	}
+	allExcludedRuleIDs = mergeWithoutDuplicates(allExcludedRuleIDs, tfsecConfig.ExcludedChecks)
+
+	options = append(options, scanner.OptionExcludeRules(allExcludedRuleIDs))
 	return options
 }
 
@@ -322,38 +345,38 @@ func mergeWithoutDuplicates(left, right []string) []string {
 	for _, x := range all {
 		set[x] = true
 	}
-	var result []string
-	for x, _ := range set {
-		result = append(result, x)
+	var results []string
+	for x := range set {
+		results = append(results, x)
 	}
 
-	return result
+	return results
 }
 
-func allInfo(results []scanner.Result) bool {
-	for _, result := range results {
-		if result.Severity != scanner.SeverityInfo && !result.Passed {
+func allInfo(results []result.Result) bool {
+	for _, res := range results {
+		if res.Severity != severity.Info && res.Status != result.Passed && res.Status != result.Ignored {
 			return false
 		}
 	}
 	return true
 }
 
-func updateResultSeverity(results []scanner.Result) []scanner.Result {
+func updateResultSeverity(results []result.Result) []result.Result {
 	overrides := tfsecConfig.SeverityOverrides
 
 	if len(overrides) == 0 {
 		return results
 	}
 
-	var overriddenResults []scanner.Result
-	for _, result := range results {
-		for code, severity := range overrides {
-			if result.RuleID == scanner.RuleCode(code) {
-				result.OverrideSeverity(severity)
+	var overriddenResults []result.Result
+	for _, res := range results {
+		for code, sev := range overrides {
+			if res.RuleID == code {
+				res.WithSeverity(severity.Severity(sev))
 			}
 		}
-		overriddenResults = append(overriddenResults, result)
+		overriddenResults = append(overriddenResults, res)
 	}
 
 	return overriddenResults
@@ -380,22 +403,16 @@ func getFormatter() (formatters.Formatter, error) {
 	}
 }
 
-func loadConfigFile(configFilePath string) *config.Config {
+func loadConfigFile(configFilePath string) (*config.Config, error) {
 	debug.Log("loading config file %s", configFilePath)
-	config, err := config.LoadConfig(configFilePath)
-	if err != nil {
-		fmt.Fprint(os.Stderr, fmt.Sprintf("Failed to load the config file. %s", err))
-		os.Exit(1)
-	}
-	debug.Log("loaded config file")
-	return config
+	return config.LoadConfig(configFilePath)
 }
 
-func countPassedResults(results []scanner.Result) int {
+func countPassedResults(results []result.Result) int {
 	passed := 0
 
-	for _, result := range results {
-		if result.Passed {
+	for _, res := range results {
+		if res.Status == result.Passed {
 			passed++
 		}
 	}
