@@ -4,14 +4,14 @@ import (
 	"encoding/json"
 	"io"
 
-	"github.com/tfsec/tfsec/internal/app/tfsec/scanner"
+	"github.com/tfsec/tfsec/pkg/result"
 )
 
 type JSONOutput struct {
-	Results []scanner.Result `json:"results"`
+	Results []result.Result `json:"results"`
 }
 
-func FormatJSON(w io.Writer, results []scanner.Result, _ string, options ...FormatterOption) error {
+func FormatJSON(w io.Writer, results []result.Result, _ string, options ...FormatterOption) error {
 	jsonWriter := json.NewEncoder(w)
 	jsonWriter.SetIndent("", "\t")
 
