@@ -3,8 +3,7 @@ package test
 import (
 	"testing"
 
-	"github.com/tfsec/tfsec/internal/app/tfsec/checks"
-	"github.com/tfsec/tfsec/internal/app/tfsec/scanner"
+	"github.com/tfsec/tfsec/internal/app/tfsec/rules"
 )
 
 func Test_AWSNotInternal(t *testing.T) {
@@ -12,8 +11,8 @@ func Test_AWSNotInternal(t *testing.T) {
 	var tests = []struct {
 		name                  string
 		source                string
-		mustIncludeResultCode scanner.RuleCode
-		mustExcludeResultCode scanner.RuleCode
+		mustIncludeResultCode string
+		mustExcludeResultCode string
 	}{
 		{
 			name: "check aws_alb when not internal",
@@ -21,7 +20,7 @@ func Test_AWSNotInternal(t *testing.T) {
 resource "aws_alb" "my-resource" {
 	internal = false
 }`,
-			mustIncludeResultCode: checks.AWSExternallyExposedLoadBalancer,
+			mustIncludeResultCode: rules.AWSExternallyExposedLoadBalancer,
 		},
 		{
 			name: "check aws_elb when not internal",
@@ -29,7 +28,7 @@ resource "aws_alb" "my-resource" {
 resource "aws_elb" "my-resource" {
 	internal = false
 }`,
-			mustIncludeResultCode: checks.AWSExternallyExposedLoadBalancer,
+			mustIncludeResultCode: rules.AWSExternallyExposedLoadBalancer,
 		},
 		{
 			name: "check aws_lb when not internal",
@@ -37,14 +36,14 @@ resource "aws_elb" "my-resource" {
 resource "aws_lb" "my-resource" {
 	internal = false
 }`,
-			mustIncludeResultCode: checks.AWSExternallyExposedLoadBalancer,
+			mustIncludeResultCode: rules.AWSExternallyExposedLoadBalancer,
 		},
 		{
 			name: "check aws_lb when not explicitly marked as internal",
 			source: `
 resource "aws_lb" "my-resource" {
 }`,
-			mustIncludeResultCode: checks.AWSExternallyExposedLoadBalancer,
+			mustIncludeResultCode: rules.AWSExternallyExposedLoadBalancer,
 		},
 		{
 			name: "check aws_lb when explicitly marked as internal",
@@ -52,7 +51,7 @@ resource "aws_lb" "my-resource" {
 resource "aws_lb" "my-resource" {
 	internal = true
 }`,
-			mustExcludeResultCode: checks.AWSExternallyExposedLoadBalancer,
+			mustExcludeResultCode: rules.AWSExternallyExposedLoadBalancer,
 		},
 	}
 
