@@ -3,8 +3,7 @@ package test
 import (
 	"testing"
 
-	"github.com/tfsec/tfsec/internal/app/tfsec/checks"
-	"github.com/tfsec/tfsec/internal/app/tfsec/scanner"
+	"github.com/tfsec/tfsec/internal/app/tfsec/rules"
 )
 
 func Test_AWSS3DataShouldBeVersioned(t *testing.T) {
@@ -12,20 +11,20 @@ func Test_AWSS3DataShouldBeVersioned(t *testing.T) {
 	var tests = []struct {
 		name                  string
 		source                string
-		mustIncludeResultCode scanner.RuleCode
-		mustExcludeResultCode scanner.RuleCode
+		mustIncludeResultCode string
+		mustExcludeResultCode string
 	}{
 		{
-			name: "Check fails if bucket has no versioning block",
+			name: "Rule fails if bucket has no versioning block",
 			source: `
 resource "aws_s3_bucket" "bad_example" {
 
 }
 `,
-			mustIncludeResultCode: checks.AWSS3DataShouldBeVersioned,
+			mustIncludeResultCode: rules.AWSS3DataShouldBeVersioned,
 		},
 		{
-			name: "Check passes if versioning block present and enabled",
+			name: "Rule passes if versioning block present and enabled",
 			source: `
 resource "aws_s3_bucket" "good_example" {
 	versioning {
@@ -33,7 +32,7 @@ resource "aws_s3_bucket" "good_example" {
 	}
 }
 `,
-			mustExcludeResultCode: checks.AWSS3DataShouldBeVersioned,
+			mustExcludeResultCode: rules.AWSS3DataShouldBeVersioned,
 		},
 	}
 
